==> mdqc_1.14.0.zip: mdqc/doc/mdqcvignette.R <==
###################################################
### chunk number 1: 
###################################################
#line 85 "mdqcvignette.Rnw"
library(mdqc)
data(allQC)
dim(allQC)
allQC[1:2,]


###################################################
### chunk number 2: 
###################################################
#line 97 "mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="nogroups") 
plot(mdout) 
print(mdout)
summary(mdout)


###################################################
### chunk number 3: 
###################################################
#line 106 "mdqcvignette.Rnw"
plot(mdout)


###################################################
### chunk number 4: 
###################################################
#line 145 "mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="apriori",
              groups=list(1:5, 6:9, 10:11))
plot(mdout) 


###################################################
### chunk number 5: 
###################################################
#line 153 "mdqcvignette.Rnw"
plot(mdout)


###################################################
### chunk number 6: 
###################################################
#line 204 "mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="cluster", k=3)
plot(mdout) 
print(mdout)


###################################################
### chunk number 7: 
###################################################
#line 212 "mdqcvignette.Rnw"
plot(mdout)


###################################################
### chunk number 8: 
###################################################
#line 232 "mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="loading", k=3, pc=4)
plot(mdout)
print(mdout)


###################################################
### chunk number 9: 
###################################################
#line 254 "mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="global", pc=4)
plot(mdout) 


###################################################
### chunk number 10: 
###################################################
#line 261 "mdqcvignette.Rnw"
plot(mdout)

==> mdqc_1.73.0.zip: mdqc/doc/mdqcvignette.R <==
### R code from vignette source 'mdqcvignette.Rnw'

###################################################
### code chunk number 1: mdqcvignette.Rnw:84-88
###################################################
library(mdqc)
data(allQC)
dim(allQC)
allQC[1:2,]


###################################################
### code chunk number 2: mdqcvignette.Rnw:96-100
###################################################
mdout <- mdqc(allQC, method="nogroups") 
plot(mdout) 
print(mdout)
summary(mdout)


###################################################
### code chunk number 3: mdqcvignette.Rnw:105-106
###################################################
plot(mdout)


###################################################
### code chunk number 4: mdqcvignette.Rnw:144-147
###################################################
mdout <- mdqc(allQC, method="apriori",
              groups=list(1:5, 6:9, 10:11))
plot(mdout) 


###################################################
### code chunk number 5: mdqcvignette.Rnw:152-153
###################################################
plot(mdout)


###################################################
### code chunk number 6: mdqcvignette.Rnw:203-206
###################################################
mdout <- mdqc(allQC, method="cluster", k=3)
plot(mdout) 
print(mdout)


###################################################
### code chunk number 7: mdqcvignette.Rnw:211-212
###################################################
plot(mdout)


###################################################
### code chunk number 8: mdqcvignette.Rnw:231-234
###################################################
mdout <- mdqc(allQC, method="loading", k=3, pc=4)
plot(mdout)
print(mdout)


###################################################
### code chunk number 9: mdqcvignette.Rnw:253-255
###################################################
mdout <- mdqc(allQC, method="global", pc=4)
plot(mdout) 


###################################################
### code chunk number 10: mdqcvignette.Rnw:260-261
###################################################
plot(mdout)
